On Sunday 21 October 2007, Cornelius Schumacher wrote:

> (all deadlines are due 23:59 UTC)
>
> 24 October (Wed): KDE 4.0 Release Freeze

I don`t really like to work in the middle of the night though. I`ve had a 
short look at the state of today, assuming that I`m supposed to tag a final 
release of the KDE 4.0 platform. 

These are the current list of showstoppers:

a) it does not even compile (see http://ktown.kde.org/~dirk/dashboard)
b) even if it would compile, it doesn`t really start up for me. 
b) there is no way currently to define a platform version number different 
than the KDE version number. 
c) kdebindings does not compile ATM

Regarding b), does it make sense to rename the current KDE_VERSION into a 
KDE_PLATFORM_VERSION and export a KDE_WORKSPACE_VERSION (not sure where we 
should get it from, has to be generated from somewhere within 
kdebase/workspace). This would be source incompatible, thought the fallout 
could be fixed pretty easily (unfinished patch attached, just to get the 
idea). 

> - Deep freeze (changes only by release team)

I don`t like the "deep freeze" terminology. I would like to have everybody 
else fix the build instead of the release team. Especially those that broke 
it ;) 

Also, I find it hard to believe that we want to go from a nearly "ignored" 
Beta3 state to a "4.0 final" state for the platform without a release 
candidate inbetween.

The additional trouble is that the new release schedule asks for a 
kdebase-runtime tarball, which does not exist yet. So I first have to create 
one and that is probably not easy in the first try. That alone justifies a 
release candidate for me. 


So, my current plans are: 

a) fix the build
b) sort out the version number mess. 
c) do a release candidate build tomorrow morning. 
d) decide on the feedback (which hopefully comes :) )


Another issue that doesn`t seem to be solved so far is that we don`#t have a 
clear list of things that are just there that are going to be deprecated with 
the 4.0 release (kjsembed? khtml? kjs? plasma layouting stuff which (I heard 
rumours) is going to be deprecated with Qt 4.4?)). 


Thanks,
Dirk
Index: kdeversion.h.cmake
===================================================================
--- kdeversion.h.cmake	(revision 728774)
+++ kdeversion.h.cmake	(working copy)
@@ -42,14 +42,14 @@
  * or for a protocol (e.g. http) be careful that it is appropriate.
  * (Fictional) example: "4.0.90 (>=20070101)"
  */
-#cmakedefine KDE_VERSION_STRING "@KDE_VERSION_STRING@"
+#cmakedefine KDE_PLATFORM_VERSION_STRING "@KDE_PLATFORM_VERSION_STRING@"
 
 /// @brief Major version of KDE, at compile time
 #cmakedefine KDE_VERSION_MAJOR @KDE_VERSION_MAJOR@
 /// @brief Minor version of KDE, at compile time
 #cmakedefine KDE_VERSION_MINOR @KDE_VERSION_MINOR@
 /// @brief Release version of KDE, at compile time
 #cmakedefine KDE_VERSION_RELEASE @KDE_VERSION_RELEASE@
 
 /**
  * @brief Make a number from the major, minor and release number of a KDE version
@@ -66,15 +66,15 @@
  * it contains the version at compile time. See versionString() if you need
  * the KDE version used at runtime.
  */
-#define KDE_VERSION \
+#define KDE_PLATFORM_VERSION \
   KDE_MAKE_VERSION(KDE_VERSION_MAJOR,KDE_VERSION_MINOR,KDE_VERSION_RELEASE)
 
 /**
  * @brief Check if the KDE version matches a certain version or is higher
  *
  * This macro is typically used to compile conditionally a part of code:
  * @code
- * #if KDE_IS_VERSION(4,0,90)
+ * #if KDE_PLATFORM_IS_VERSION(4,0,90)
  * // Code for KDE 4.1
  * #else
  * // Code for KDE 4.0
@@ -89,7 +89,7 @@
  * e.g. for KDE 4.1 with KDE_IS_VERSION(4,1,0)
  * but with the actual version number at a time a needed feature was introduced.
  */
-#define KDE_IS_VERSION(a,b,c) ( KDE_VERSION >= KDE_MAKE_VERSION(a,b,c) )
+#define KDE_PLATFORM_IS_VERSION(a,b,c) ( KDE_PLATFORM_VERSION >= KDE_MAKE_VERSION(a,b,c) )
 
 /**
  * Namespace for general KDE functions.
@@ -97,33 +97,34 @@
 namespace KDE
 {
     /**
      * @brief Returns the encoded number of KDE's version, see the KDE_VERSION macro.
      *
      * In contrary to the macro KDE_VERSION
      * this function returns the number of the actually
      * installed KDE version, not the number of the KDE version that was
      * installed when the program was compiled.
      * @return the version number, encoded in a single uint
      */
-    KDECORE_EXPORT unsigned int version();
+    KDECORE_EXPORT unsigned int platformVersion();
     /**
      * @brief Returns the major number of KDE's version, e.g.
      * 4 for KDE 4.1.2. 
      * @return the major version number
      */
-    KDECORE_EXPORT unsigned int versionMajor();
+    KDECORE_EXPORT unsigned int platformVersionMajor();
     /**
      * @brief Returns the minor number of KDE's version, e.g.
      * 1 for KDE 4.1.2. 
      * @return the minor version number
      */
-    KDECORE_EXPORT unsigned int versionMinor();
+    KDECORE_EXPORT unsigned int platformVersionMinor();
     /**
      * @brief Returns the release of KDE's version, e.g.
      * 2 for KDE 4.1.2. 
      * @return the release number
      */
-    KDECORE_EXPORT unsigned int versionRelease();
+    KDECORE_EXPORT unsigned int platformVersionRelease();
     /**
      * @brief Returns the KDE version as string, e.g. "4.1.2".
      *
@@ -131,7 +132,7 @@ namespace KDE
      * the version number of KDE at runtime.
      * @return the KDE version. You can keep the string forever
      */
-    KDECORE_EXPORT const char *versionString();
+    KDECORE_EXPORT const char *platformVersionString();
 }
 
 #endif // KDELIBS_KDEVERSION_H
@@ -42,14 +42,14 @@
 
-/// @brief Major version of KDE, at compile time
-#cmakedefine KDE_VERSION_MAJOR @KDE_VERSION_MAJOR@
-/// @brief Minor version of KDE, at compile time
-#cmakedefine KDE_VERSION_MINOR @KDE_VERSION_MINOR@
-/// @brief Release version of KDE, at compile time
-#cmakedefine KDE_VERSION_RELEASE @KDE_VERSION_RELEASE@
+/// @brief Major version of KDE platform, at compile time
+#cmakedefine KDE_PLATFORM_VERSION_MAJOR @KDE_VERSION_MAJOR@
+/// @brief Minor version of KDE platform, at compile time
+#cmakedefine KDE_PLATFORM_VERSION_MINOR @KDE_VERSION_MINOR@
+/// @brief Release version of KDE platform, at compile time
+#cmakedefine KDE_PLATFORM_VERSION_RELEASE @KDE_VERSION_RELEASE@
 
 /**
@@ -66,15 +66,15 @@
 
 /**
- * @brief Check if the KDE version matches a certain version or is higher
+ * @brief Check if the KDE platform version matches a certain version or is higher
  *
  * This macro is typically used to compile conditionally a part of code:
@@ -97,33 +97,34 @@
 {
     /**
-     * @brief Returns the encoded number of KDE's version, see the KDE_VERSION macro.
+     * @brief Returns the encoded number of KDE's platform version, 
+     * see the KDE_PLATFORM_VERSION macro.
      *
@@ -97,33 +97,34 @@
      *
-     * In contrary to the macro KDE_VERSION
+     * In contrary to the macro KDE_PLATFORM_VERSION
      * this function returns the number of the actually
      * installed KDE version, not the number of the KDE version that was
@@ -97,33 +97,34 @@
     /**
-     * @brief Returns the major number of KDE's version, e.g.
+     * @brief Returns the major number of KDE's platform version, e.g.
      * 4 for KDE 4.1.2. 
      * @return the major version number
_______________________________________________
release-team mailing list
[email protected]
https://mail.kde.org/mailman/listinfo/release-team

Reply via email to